@@ -1,3 +1,3 @@
 from .functions import *
-from .mlp import MLP
+from .mlp import MLP, NN
 from .replay_buffer import ReplayBuffer
\ No newline at end of file
