@@ -5,4 +5,5 @@ class TileType(Enum):
     EMPTY = 0
     WALL = 1
     START = 2
-    TERMINAL = 3
\ No newline at end of file
+    REWARD = 3
+    TERMINAL_FAIL = 4
\ No newline at end of file
